@@ -24,7 +24,6 @@ from mistralclient.api import client as mistral_client
 from novaclient.client import Client as nova_client
 from swiftclient import client as swift_client
 from swiftclient import exceptions as swiftexceptions
-from zaqarclient.queues.v2 import client as zaqarclient
 
 from tripleo_common import constants
 from tripleo_common.utils import keystone as keystone_utils
@@ -106,23 +105,6 @@ class TripleOAction(actions.Action):
             username=context.user_name
         )
 
-    def get_messaging_client(self, context):
-        zaqar_endpoint = keystone_utils.get_endpoint_for_project(
-            context, service_type='messaging')
-        keystone_endpoint = keystone_utils.get_endpoint_for_project(
-            context, 'keystone')
-
-        opts = {
-            'os_auth_token': context.auth_token,
-            'os_auth_url': keystone_endpoint.url,
-            'os_project_id': context.project_id,
-            'insecure': context.insecure,
-        }
-        auth_opts = {'backend': 'keystone', 'options': opts}
-        conf = {'auth_opts': auth_opts}
-
-        return zaqarclient.Client(zaqar_endpoint.url, conf=conf)
-
     def get_workflow_client(self, context):
         mistral_endpoint = keystone_utils.get_endpoint_for_project(
             context, 'mistral')
@@ -138,6 +120,7 @@ class TripleOAction(actions.Action):
         nova_endpoint = keystone_utils.get_endpoint_for_project(
             context, 'nova')
 
+        # TODO(apetrich) Change this auth to a keystone session
         client = nova_client(
             2,
             username=None,
@@ -147,7 +130,9 @@ class TripleOAction(actions.Action):
             tenant_id=context.project_id,
             region_name=keystone_endpoint.region,
             auth_url=keystone_endpoint.url,
-            insecure=context.insecure
+            insecure=context.insecure,
+            project_domain_name="Default",
+            user_domain_name="Default"
         )
 
         client.client.management_url = keystone_utils.format_url(
