@@ -28,7 +28,7 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: tripleopike/heat-docker-agents-centos:current-tripleo
+    - imagename: tripleoupstream/heat-docker-agents-centos:latest
       push_destination: localhost:8787
     - imagename: tripleoupstream/centos-binary-nova-compute:liberty
       uploader: docker
@@ -43,7 +43,7 @@ filedata = six.u(
 
 legacy_filedata = six.u(
     """uploads:
-    - imagename: tripleopike/heat-docker-agents-centos:current-tripleo
+    - imagename: tripleoupstream/heat-docker-agents-centos:latest
       push_destination: localhost:8787
     - imagename: tripleoupstream/centos-binary-nova-compute:liberty
       uploader: docker
@@ -234,23 +234,6 @@ class TestDockerImageUploader(base.TestCase):
         self.assertRaises(ImageUploaderException,
                           self.uploader.discover_image_tag, image, 'foo')
 
-    def test_discover_image_tag_with_port(self):
-        image = 'foo:5000/t/heat-docker-agents-centos:latest'
-        vimage = 'foo:5000/t/heat-docker-agents-centos:1.2.3'
-
-        dockerc = self.dockermock.return_value
-        dockerc.pull.return_value = ['{"status": "done"}']
-        dockerc.inspect_image.return_value = {
-            'Config': {'Labels': {'image-version': '1.2.3'}}
-        }
-        result = self.uploader.discover_image_tag(image, 'image-version')
-        self.assertEqual('1.2.3', result)
-
-        dockerc.pull.assert_has_calls([
-            mock.call(image, tag=None, stream=True),
-            mock.call(vimage, tag=None, stream=True),
-        ])
-
     @mock.patch('time.sleep')
     def test_pull_retry(self, sleep_mock):
         image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
